Struct glean::private::EventMetric
source · pub struct EventMetric<K> { /* private fields */ }Expand description
Developer-facing API for recording event metrics.
Instances of this class type are automatically generated by the parsers at build time, allowing developers to record values that were previously registered in the metrics.yaml file.
Implementations
sourceimpl<K: ExtraKeys> EventMetric<K>
impl<K: ExtraKeys> EventMetric<K>
sourcepub fn new(meta: CommonMetricData) -> Self
pub fn new(meta: CommonMetricData) -> Self
The public constructor used by automatically generated metrics.
sourcepub fn with_runtime_extra_keys(
meta: CommonMetricData,
allowed_extra_keys: Vec<String>,
) -> Self
pub fn with_runtime_extra_keys( meta: CommonMetricData, allowed_extra_keys: Vec<String>, ) -> Self
The public constructor used by runtime-defined metrics.
sourcepub fn record_with_time(&self, timestamp: u64, extra: HashMap<String, String>)
pub fn record_with_time(&self, timestamp: u64, extra: HashMap<String, String>)
Record a new event with a provided timestamp.
It’s the caller’s responsibility to ensure the timestamp comes from the same clock source.
Use glean::get_timestamp_ms to get a valid timestamp.
sourceimpl<K> EventMetric<K>
impl<K> EventMetric<K>
sourceimpl<K> EventMetric<K>
impl<K> EventMetric<K>
sourcepub fn test_get_value(
&self,
ping_name: Option<String>,
) -> Option<Vec<RecordedEvent>>
pub fn test_get_value( &self, ping_name: Option<String>, ) -> Option<Vec<RecordedEvent>>