Struct glean::private::ObjectMetric
source · pub struct ObjectMetric<K> { /* private fields */ }Expand description
Developer-facing API for recording object metrics.
Instances of this class type are automatically generated by the parsers at build time, allowing developers to record values that were previously registered in the metrics.yaml file.
Implementations
sourceimpl<K: ObjectSerialize> ObjectMetric<K>
impl<K: ObjectSerialize> ObjectMetric<K>
sourcepub fn new(meta: CommonMetricData) -> Self
pub fn new(meta: CommonMetricData) -> Self
The public constructor used by automatically generated metrics.
sourcepub fn set_string(&self, object: String)
pub fn set_string(&self, object: String)
Sets to the specified structure.
Parses the passed JSON string. If it can’t be parsed into a valid object it records an invalid value error.
Arguments
object- JSON representation of the object to set.